@@ -9,7 +9,7 @@ class ParseError(Exception):
     pass
 
 
-class Parser:
+class Parser:  # pylint: disable=too-many-public-methods
     """Parses a sequence of Tokens and returns an abstract syntax tree.
 
     Parameters
@@ -24,7 +24,7 @@ class Parser:
         # pass options to understand custom functionality
 
     def at_end(self):
-        return self.peek().type == "EOF"
+        return self.peek().kind == "EOF"
 
     def advance(self):  # pylint: disable=inconsistent-return-statements
         if not self.at_end():
@@ -43,7 +43,7 @@ class Parser:
         # Checks multiple types at once
         if self.at_end():
             return False
-        return self.peek().type in listify(types)
+        return self.peek().kind in listify(types)
 
     def match(self, types):
         if self.check(types):
@@ -52,14 +52,14 @@ class Parser:
         else:
             return False
 
-    def consume(self, _type, message):
+    def consume(self, kind, message):
         """Consumes the next Token
 
-        First, it checks if the next Token is of the expected type.
+        First, it checks if the next Token is of the expected kind.
         If True, it calls self.advance() and it's Saul Goodman.
         Otherwise, we've found an error.
         """
-        if self.check(_type):
+        if self.check(kind):
             return self.advance()
         else:
             raise ParseError(message)
@@ -95,8 +95,18 @@ class Parser:
         return expr
 
     def random_effect(self):
-        expr = self.addition()
+        expr = self.comparison()
         while self.match(["PIPE"]):
+            operator = self.previous()
+            right = self.comparison()
+            expr = Binary(expr, operator, right)
+        return expr
+
+    def comparison(self):
+        expr = self.addition()
+        while self.match(
+            ["EQUAL_EQUAL", "BANG_EQUAL", "LESS_EQUAL", "LESS", "GREATER_EQUAL", "GREATER"]
+        ):
             operator = self.previous()
             right = self.addition()
             expr = Binary(expr, operator, right)
@@ -166,9 +176,6 @@ class Parser:
             identifier = self.previous()
             if self.match("LEFT_BRACKET"):
                 level = self.primary()
-                if not isinstance(level, (Literal, Variable)):
-                    raise ParseError("Subset notation only allows a string or an identifer.")
-
                 if isinstance(level, Literal) and not isinstance(level.value, str):
                     raise ParseError("Subset notation only allows a string or an identifer.")
 
@@ -196,5 +203,5 @@ class Parser:
             expr = self.expression()
             self.consume("RIGHT_BRACE", "Expect '}' after expression.")
             return Call(Variable(Token("IDENTIFIER", "I")), [expr])
-        else:
+        else:  # pragma: no cover
             raise ParseError(f"Don't know how to parse '{self.peek().lexeme}'")
